% solve u_xx = c^2 * u_tt
% x := space coordinate [0,a].
% t := time [0,T].
% u := the function to be solved.

% initial condition   : u(x,t=0) = sin(pi*x).
% initial velocity    : u_t(x,t=0) = V(x) = 0.
% boundary conditions : u(x=0,t) = u(x=a,t) = 0.


c = 3.0;
a = 5.0;
T = 10.0;

time_step = 1.0e-3; 
x_step = 1.0e-2;

const = c*time_step/x_step;
const = const*const;

Ntime = floor(T/time_step) + 1;
Nx = floor(a/x_step) + 1;

x = zeros(Ntime,Nx);

tic;

% set up initial condition:
for jt = 1 : Ntime
    u(jt,1)  = 0.0;
    u(jt,Nx) = 0.0;
end

for ix = 2 : Nx-1
    u(1,ix) = sin(pi*x_step*ix);
    u(2,ix) = 0.5*const * ( u(1,ix+1) + u(1,ix-1) ) + (1.0-const) * u(1,ix); 
end

for jt = 2 : Ntime-1
for ix = 2 : Nx-1
    u(jt+1,ix) = 2.0*(1.0-const)*u(jt,ix) + const*(u(jt,ix+1) + u(jt,ix-1)) - u(jt-1,ix);
end
end

toc;
